View a specific tutorial. Usage: /tutorial <number>

Arguments: $ARGUMENTS

Based on the tutorial number provided in $ARGUMENTS:

1. If a number is provided (1-16):
   - Read examples/{number}_*/README.md
   - Read examples/{number}_*/run.py
   - Explain the key concepts
   - Show the important code sections

2. If no number is provided:
   - List all 16 tutorials with their topics
   - Ask the user which one they want to view

Tutorial mapping:
- 01: Getting Started (basic energy)
- 02: Convergence Testing
- 03: Structure Relaxation
- 04: Equation of State
- 05: Density of States
- 06: Band Structure
- 07: Magnetism
- 08: Surfaces
- 09: Adsorption
- 10: Reactions
- 11: Phonons
- 12: DFT+U
- 13: Hybrid Functionals
- 14: Van der Waals
- 15: Workflows
- 16: NEB (Nudged Elastic Band)
